%global libmodulemd_version 2.6.0
%global libmodulemd_v1_version 1.8.13

Name:           libmodulemd1
Version:        %{libmodulemd_v1_version}
Release:        1%{?dist}
Summary:        Module metadata manipulation library

License:        MIT
URL:            https://github.com/fedora-modularity/libmodulemd
Source0:        %{url}/releases/download/libmodulemd-%{libmodulemd_version}/modulemd-%{libmodulemd_version}.tar.xz

BuildRequires:  meson >= 0.47
BuildRequires:  pkgconfig
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(yaml-0.1)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  python2-devel
BuildRequires:  python-gobject-base
BuildRequires:  python36-devel
BuildRequires:  python36-gobject-base
%ifarch %{valgrind_arches}
BuildRequires:  valgrind
%endif

Obsoletes: libmodulemd < 2
Provides: libmodulemd = %{version}-%{release}
Provides: libmodulemd%{?_isa} = %{version}-%{release}

# Patches


%description
C Library for manipulating module metadata files.
See https://github.com/fedora-modularity/libmodulemd/blob/master/README.md for
more details.


%package -n python2-%{name}
Summary: Python 2 bindings for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: python-gobject-base
Obsoletes: python2-modulemd < 1.3.4

%description -n python2-%{name}
Python 2 bindings for %{name}


%package -n python36-%{name}
Summary: Python 3.6 bindings for %{name}
Requires: %{name}%{?_isa} = %{version}-%{release}
Requires: python36-gobject-base
Obsoletes: python3-modulemd < 1.3.4

%description -n python36-%{name}
Python 3.6 bindings for %{name}


%package devel
Summary:        Development files for libmodulemd
Requires:       %{name}%{?_isa} = %{version}-%{release}
Conflicts:      libmodulemd-devel

%description devel
Development files for libmodulemd.


%prep
%autosetup -p1 -n modulemd-%{libmodulemd_version}


%build
%meson -Ddeveloper_build=false -Dbuild_api_v1=true -Dbuild_api_v2=false -Dwith_py2_overrides=false -Dwith_py3_overrides=false
%meson_build


%check

export LC_CTYPE=C.utf8

%ifarch %{power64} s390x
# Valgrind is broken on ppc64[le] with GCC7:
# https://bugs.kde.org/show_bug.cgi?id=386945
export MMD_SKIP_VALGRIND=1
%endif
%ifnarch %{valgrind_arches}
export MMD_SKIP_VALGRIND=1
%endif

# Don't run tests on ARM for now. There are problems with
# performance on the builders and often these time out.
%ifnarch %{arm} aarch64
%meson_test
%endif


%install
%meson_install


%files
%license COPYING
%doc README.md
%{_bindir}/modulemd-validator-v1
%{_libdir}/libmodulemd.so.1*
%dir %{_libdir}/girepository-1.0
%{_libdir}/girepository-1.0/Modulemd-1.0.typelib


%files devel
%{_libdir}/libmodulemd.so
%{_libdir}/pkgconfig/modulemd.pc
%{_includedir}/modulemd/
%dir %{_datadir}/gir-1.0
%{_datadir}/gir-1.0/Modulemd-1.0.gir
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/modulemd-1.0/

%files -n python36-%{name}


%files -n python2-%{name}


%changelog
* Wed Jul 03 2019 Stephen Gallagher <sgallagh@redhat.com> - 2.6.0-1
- Update to 2.6.0
- New function ModuleIndexMerger.resolve_ext() allowing for strict merging
- Profile.get_description() now properly returns available translations
- Numerous documentation fixes
- Test improvements

* Wed May 29 2019 Stephen Gallagher <sgallagh@redhat.com> - 2.5.0-2
- Fix memory issue with Module.search_streams() in the python bindings

* Wed May 22 2019 Stephen Gallagher <sgallagh@redhat.com> - 2.5.0-1
- Update to 2.5.0 and 1.8.11
- Ensure that XMD is always emitted in the same order
- Add .clear_*() functions for all .add_*() functions
- Add ModuleStream.equals()
- Add ModuleIndex.get_default_streams()

* Mon May 13 2019 Stephen Gallagher <sgallagh@redhat.com> - 2.4.0-1
- Update to 2.4.0 and 1.8.10
- Add ModuleStreamV2.clear_dependencies() and .remove_dependencies()
- Fix bugs and memory issues with the XMD python bindings
- Assorted documentation enhancements

* Fri May 03 2019 Stephen Gallagher <sgallagh@redhat.com> - 2.3.1-1
- Update to 2.3.1
- Make Modulemd.Component.set_*() functions accept NULL
- Fix segmentation fault in XMD code due to improper memory management
- Fix incompatibility in python2-libmodulemd GObject overrides
- Fix assorted documentation issues

* Wed Mar 27 2019 Stephen Gallagher <sgallagh@redhat.com> - 1.8.5-1
- Update to libmodulemd 1.8.5 with proper python 2 support

* Wed Mar 27 2019 Stephen Gallagher <sgallagh@redhat.com> - 1.8.4-1
- Release libmodulemd1 1.8.4 for COPR on EPEL 7

